function [ order, cases ] = determineOrder( rate, SOZ, RV )
%% function [ order, cases ] = determineOrder( rate, SOZ, RV )
%
%   Determine optimal order for the given rates
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

%% prep

nChan = size(rate, 1);

%% set up cases

haveRV = false;
haveSOZ = false;

if( any(isfinite(RV)) )
    haveRV = true;
    if( any(isfinite(SOZ)) )
        haveSOZ = true;
        cases{1} = ~RV & SOZ;
        cases{2} = RV & SOZ;
        cases{3} = RV & ~SOZ;
        cases{4} = ~RV & ~SOZ;
    else
        cases{1} = [];
        cases{2} = RV;
        cases{3} = [];
        cases{4} = ~RV;
    end
elseif( any(isfinite(SOZ)) )
    haveSOZ = true;
    cases{1} = SOZ;
    cases{2} = [];
    cases{3} = [];
    cases{4} = ~SOZ;
else
    cases{1} = [];
    cases{2} = [];
    cases{3} = [];
    cases{4} = 1:nChan;
end

cases{5} = struct('haveSOZ', haveSOZ, 'haveRV', haveRV );

%% determine order

order = cell(1,4);
type = 'correlation';
nonZero = any( rate' );

for i=1:4

  %%order{i} = flip(find(cases{i}));

    if( sum(cases{i}) == 1 )
        order{i} = find(cases{i});
    elseif( sum(cases{i}) > 1 )
        if( sum( cases{i}(:) & nonZero(:) ) < 3 )
            order{i} = find(cases{i});
        else
            Y = pdist( rate(cases{i} & nonZero,:), type);
            Z = linkage(Y);
            
            temp = find(cases{i} & nonZero);
            temp_order = optimalleaforder( Z, Y );
            temp_order = [ find(cases{i} & ~nonZero) temp(temp_order)];
            order{i} = flip(temp_order);
        end
    end
    cases{i} = find(cases{i});
end
order = cell2mat(order);

end

