function [ harray, h ] = gbar2( x, y, n, colors, doNormalize, x_range )
%%function [ harray, h ] = gbar2( x, y, n, colors, doNormalize, x_range )
%
% Mimic gscatter for histograms (bar graphs).
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

if( nargin < 5 )
    doNormalize = 0;
end
if( nargin < 6 )
  z = [x(:); y(:)];
  x_range = [min(z), max(z)];
end

x1 = x_range(1);
x2 = x_range(2);

edges = linspace( x1, x2, n+1 );
edges(end) = edges(end)+eps;
nlabels = 2;
if( length(colors) ~= nlabels && ~isempty(colors) )
    err = MException('gbar:inputMismatch', 'Number of colors does not match number of labels');
    throw(err);
end

h = zeros(length(edges),nlabels);

h(:,1) = histc( x, edges );
h(:,2) = histc( y, edges );

if( doNormalize )
  for i=1:nlabels
    h(:,i) = h(:,i) / sum(h(:,i));
  end
end

harray = bar( edges, h, 'histc' );
xlim( x_range );

if( ~isempty(colors) )
    for i=1:nlabels
        if( isa(colors,'cell') )
            set( harray(i), 'FaceColor', colors{i} );
            set( harray(i), 'EdgeColor', colors{i} );
        else
            set( harray(i), 'FaceColor', colors(i) );
            set( harray(i), 'EdgeColor', colors(i) );
        end
    end
end

if nargout < 1
harray = [];
h = [];
end

end

