function plot_UMHS_0007()
%% function plot_UMHS_0007()
%
% Produce the plot of HFO counts for subject UMHS-0007 vs. seizure times.
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

set(gcf, 'Renderer', 'painters', ...
    'InvertHardcopy','on',...
    'Position',[0 0 1500 600]+50,...
    'PaperPositionMode','auto');


%%

dayWidth = 4;

%% load and plot other data

f = load('data/UMHS-NREM.qHFO_v2.2.inputData.mat');
g = load('data/UMHS-NREM.qHFO_v2.2.results.mat');
r = f.data(3);
r.bss = g.results(3).bss;

x1 = mod(r.startHour,24);
x2 = x1 + 10/60;

shift = 1; %(dayWidth - 3 )/2;
y1 = -dayWidth*floor(r.startHour/24)+shift;
y2 = y1 - 1;

% offset for days

clf
axes('position', [0.08 0.12 0.91 0.85]);
x1 = [x1   x1   x1];
x2 = [x2   x2   x2];
y1 = [y1+1 y1+2 y1+3];
y2 = [y2+1 y2+2 y2+3];
z  = flipud(r.bss(1).H)';
z = z(:);
z =  [z; z; z];

plot_heatMap_patches( x1, x2, y1, y2, z );
caxis([0 max(z)/60]);

%% lines

for i=5:13
    line( [0 24], -dayWidth*[i i], 'color', 'k' );
end

%% load Sz times
X = load('data/UMHS-0007-electrographic-seizures.txt');
I = X(:,end) > 0;
X = X(I,:);

x = X * [24 1 1/60 1/3600 0]';

u = unique(X(:,end));
c = zeros(size(x));
for i=1:length(u)
    c( X(:,end) == u(i) ) = i;
end

y = -dayWidth*floor(x/24);
x = mod(x,24);

%% plot Sz

purple = [112 48 160]/255;
red = [255 0 0 ]/255;
orange = [246 117 10]/255;
black = [0 0 0]/255;
blue = [0 112 192]/255;

colors = { purple, red, orange, black, blue };

x1 = x;
x2 = x + 5/60;
y1 = y;
y2 = y+1;

plot_heatMap_patches( x1, x2, y1, y2, c, cell2mat(colors') );

%% make pretty

hold on
hSz  = gscatter( -ones(1,5), -ones(1,5), 1:5 );
hold off
for i=1:5
    hSz(i).Marker = 's';
    hSz(i).MarkerFaceColor = colors{i};
    hSz(i).MarkerEdgeColor = colors{i};
    hSz(i).MarkerSize = 10;
end
legend(hSz, {'Seizure Type 1', 'Seizure Type 2', 'Seizure Type 3', 'Seizure Type 4', 'Seizure Type 5'}, 'Location', 'SouthEastOutside', 'fontsize', 18);

xlim([0 24]);
ylim([-14 -4]*dayWidth);

%%
h = gca;
h.XTick = 0:3:24;
h.XRuler.TickLabelFormat = '%d:00';
h.XRuler.TickLength = [ 0.008 0 ];

h.YTick = (-13.5:-4)*dayWidth;
h.YTickLabel = arrayfun( @(x) sprintf('day %d', x), 14:-1:0, 'uniformoutput', false );
h.YRuler.TickLength = [ 0 0 ];

xlabel('Time of Day');

%% colorbar
colorbar
h = colorbar;
xlabel(h,'Arbitrary units', 'fontsize', 18);
h.Label.Units = 'normalized';
h.Position = [0.838 0.38 0.02 0.6];

%%
set(gca,'fontsize',18);
text(0.2, -dayWidth*4.5, {'Channel Group 1', 'Channel Group 2', 'Channel Group 3', 'Seizures'}, 'fontsize', 8);

%%
print('plots/UMHS_sz_times.eps', '-depsc');

