function h = plot_heatMap_patches( x1, x2, y1, y2, z, cMap )
%% function h = plot_heatMap_patches( x1, x2, y1, y2, z )
%
%  Plot heat map via patches.  Internal script for "plot_UMHS_0007.m"
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

%% prep

num = max(length(x1), length(y1));

assert( length(x1) == length(x2), 'Size of x1 does not match x2' );
assert( length(y1) == length(y2), 'Size of y1 does not match y2' );

if( length(x1) == 1 )
    x1 = x1*ones(num,1);
    x2 = x2*ones(num,1);
elseif( length(y1) == 1 )
    y1 = y1*ones(num,1);
    y2 = y2*ones(num,1);
end

assert( length(x1) == num, 'Size of x1 does not match' );
assert( length(y1) == num, 'Size of y1 does not match' );
assert( length(z)  == num, 'Size of z does not match' );

%% compute

faces = reshape( 1:num*4, num, 4 );
verts = [ x1(:) y1(:); x2(:) y1(:); x2(:) y2(:); x1(:) y2(:) ];

if( nargin < 6 )
    Ncol = 100;
    cMap = colormap(parula(Ncol));
    
    colors = (z - nanmin(z));
    if( nanmax(colors) ~= 0 )
        colors = colors / nanmax(colors);
    end
    colors = floor( colors*(Ncol-1) )+1;
    colors = cMap(colors,:);
else
    colors = cMap(z,:);
end



%% output

h = patch( 'faces', faces, 'vertices', verts, 'faceVertexCdata', repmat(colors,4,1), 'FaceColor', 'flat', 'EdgeColor', 'none' );
